import os
import tempfile


class Config:
    lineEnd = "\n"
    biLineEnd = "\n\n"
    triLineEnd = "\n\n\n"
    undrln = "_"
    blank = " "
    tab = "\t"
    star = "*"
    slash = "/"
    comma = ","
    delimInFeature = "."
    B = "B"
    num = "0123456789.几二三四五六七八九十千万亿兆零１２３４５６７８９０％"
    letter = "ＡＢＣＤＥＦＧＨＩＪＫＬＭＮＯＰＱＲＳＴＵＶＷＸＹＺａｂｃｄｅｆｇｈｉｇｋｌｍｎｏｐｑｒｓｔｕｖｗｘｙｚ／・－"
    mark = "*"
    model_urls = {
        "bert-base-2": 'https://gitlab.sz.sensetime.com/scg-nlp-research/cws/-/raw/v0.0.2/cwseg/cwseg/released_models/bert-base-2.zip?inline=false',
    }
    model_hash = {
        "bert-base-2": None,
    }
    dict_urls = {
        "bert-base-2": 'https://gitlab.sz.sensetime.com/scg-nlp-research/cws/-/raw/v0.0.2/cwseg/cwseg/dicts/vocab_set.json?inline=false',
    }
    dict_hash = {
        "bert-base-2": None,
    }
    available_models = ["bert-base-2"]
    models_with_dict = ["bert-base-2"]

    def __init__(self):
        # main setting
        self.cwseg_home = os.path.expanduser(os.getenv('CWSEG_HOME', '~/.cwseg'))
        self.trainFile = os.path.join("data", "small_training.utf8")
        self.testFile = os.path.join("data", "small_test.utf8")
        self._tmp_dir = tempfile.TemporaryDirectory()
        self.homepath = self._tmp_dir.name
        self.tempFile = os.path.join(self.homepath, ".cwseg", "temp")
        self.readFile = os.path.join("data", "small_test.utf8")
        self.outputFile = os.path.join("data", "small_test_output.utf8")

        # global variables
        self.testrawDir = "rawinputs/"
        self.testinputDir = "inputs/"
        self.tempDir = os.path.join(self.homepath, ".cwseg", "temp")
        self.testoutputDir = "entityoutputs/"

        self.c_train = os.path.join(self.tempFile, "train.conll.txt")
        self.f_train = os.path.join(self.tempFile, "train.feat.txt")

        self.c_test = os.path.join(self.tempFile, "test.conll.txt")
        self.f_test = os.path.join(self.tempFile, "test.feat.txt")

        self.fTune = "tune.txt"
        self.fLog = "trainLog.txt"
        self.fResSum = "summarizeResult.txt"
        self.fResRaw = "rawResult.txt"
        self.fOutput = "outputTag-{}.txt"

        self.fFeatureTrain = os.path.join(self.tempFile, "ftrain.txt")
        self.fGoldTrain = os.path.join(self.tempFile, "gtrain.txt")
        self.fFeatureTest = os.path.join(self.tempFile, "ftest.txt")
        self.fGoldTest = os.path.join(self.tempFile, "gtest.txt")

        self.modelDir = os.path.join(
            os.path.dirname(os.path.realpath(__file__)), "models", "ctb8"
        )
        self.fModel = os.path.join(self.modelDir, "model.txt")


config = Config()
